#!perl

use strict;
use warnings;

use Test::More;



  plan tests => 1;

use_ok('Dist::Zilla::PluginBundle::FAYLAND');
diag("Testing Dist::Zilla::PluginBundle::FAYLAND $Dist::Zilla::PluginBundle::FAYLAND::VERSION, Perl $], $^X");
